@@ -1,4 +1,3 @@
-
 /*
  * (C) Copyright 2005- ECMWF.
  *
@@ -16,16 +15,13 @@
 class grib_accessor_codetable_units_t : public grib_accessor_gen_t
 {
 public:
-    /* Members defined in codetable_units */
-    const char* codetable;
-};
-
-class grib_accessor_class_codetable_units_t : public grib_accessor_class_gen_t
-{
-public:
-    grib_accessor_class_codetable_units_t(const char* name) : grib_accessor_class_gen_t(name) {}
+    grib_accessor_codetable_units_t() :
+        grib_accessor_gen_t() { class_name_ = "codetable_units"; }
     grib_accessor* create_empty_accessor() override { return new grib_accessor_codetable_units_t{}; }
-    int get_native_type(grib_accessor*) override;
-    int unpack_string(grib_accessor*, char*, size_t* len) override;
-    void init(grib_accessor*, const long, grib_arguments*) override;
+    long get_native_type() override;
+    int unpack_string(char*, size_t* len) override;
+    void init(const long, grib_arguments*) override;
+
+private:
+    const char* codetable_ = nullptr;
 };
